@@ -72,9 +72,7 @@ int sc_main (int argc, char *argv[]) {
 #ifndef NC_SYSTEMC
     // SystemC traces are flawed, you can't even trace ports
     sc_trace_file *tf = sc_create_vcd_trace_file("sim_sc" );
-# ifndef _SC_LITE_
     sc_trace(tf, clk, "clk");
-# endif // NC_SYSTEMC
 
 #if SYSTEMC_VERSION >= 20070314
     tf->set_time_unit(1, SC_NS);
